@@ -157,12 +157,13 @@
 # ################################################################################
 # ################################################################################
 logsigma2 <- seq(-2, 4.5, by = .25)
-kTaus <- Vectorize(function(lnSigma2) 
+kTaus <- Vectorize(function(lnSigma2)
   parfm:::fr.lognormal(what = 'tau', sigma2 = exp(lnSigma2)))
 # plot(exp(logsigma2), kTaus_ln(logsigma2))
 
 find.sigma2 <- function(tau) {
-  loss <- function(x) (kTaus(x) - tau)^2
+  loss <- function(x)
+    (kTaus(x) - tau) ^ 2
   RES <- optimize(loss, c(-10, 4))
   return(exp(RES$minimum))
 }
@@ -466,51 +467,69 @@ simData <- function(method = c('re', 'cc', 'mx')) {
     mstT = 8*365.25     # median survival time for T in the control arm
     ############################################################################
   ) {
+    
     if (length(gammaWei) == 1)
       gammaWei <- rep(gammaWei, 2)
     
     if (nifix) {
       trialref <- rep(1:N, each = ni)
     } else {
-      trialref <- sort(sample(1:N, N * ni, replace = TRUE, prob = rpois(N, 5)))
+      trialref <-
+        sort(sample(1:N, N * ni, replace = TRUE, prob = rpois(N, 5)))
     }
     
-    data <- data.frame(
-      trialref = factor(trialref),
-      trt = rbinom(n = ni * N, size = 1, prob = 0.5) - .5
-    )
-    data$id <- factor(mapply(paste, data$trialref, 
-                             unlist(lapply(table(data$trialref), function(x) 1:x)),
-                             #rep(1:ni, N), 
-                             sep='.'))
+    data <- data.frame(trialref = factor(trialref),
+                       trt = rbinom(n = ni * N, size = 1, prob = 0.5) - .5)
+    data$id <- factor(mapply(paste, data$trialref,
+                             unlist(lapply(table(data$trialref), function(x)
+                               1:x)),
+                             #rep(1:ni, N),
+                             sep = '.'))
     
     # First stage: random effects ******************************************** #
     # Trial-level
-    muS <- log(log(2) / mstS) * (-1)^(method == 'mx')
-    muT <- log(log(2) / mstT) * (-1)^(method == 'mx')
+    muS <- log(log(2) / mstS) * (-1) ^ (method == 'mx')
+    muT <- log(log(2) / mstT) * (-1) ^ (method == 'mx')
     d_ab <- sqrt(R2 * alphaVar * betaVar)
     d_ST <- sqrt(baseCorr) * sqrt(prod(baseVars))
-    Sigma_trial <- matrix(c(baseVars[1],        d_ST,        0,       0,
-                            d_ST,        baseVars[2],        0,       0,
-                            0,                     0, alphaVar,    d_ab,
-                            0,                     0,     d_ab, betaVar ), 4)
+    Sigma_trial <-
+      matrix(c(
+        baseVars[1],
+        d_ST,
+        0,
+        0,
+        d_ST,
+        baseVars[2],
+        0,
+        0,
+        0,
+        0,
+        alphaVar,
+        d_ab,
+        0,
+        0,
+        d_ab,
+        betaVar
+      ),
+      4)
     #   library('MASS')
-    pars <- mvrnorm(n= N, mu = c(muS, muT, alpha, beta), 
+    pars <- mvrnorm(n = N,
+                    mu = c(muS, muT, alpha, beta),
                     Sigma = Sigma_trial)
-    pars <- pars[data$trialref, ]
+    pars <- pars[data$trialref,]
     
     ATTRs <- list(
-      'N'=N,
-      'ni'=ni,
-      'gammaWei'= gammaWei,
-      'censorT'= ifelse(missing(censorT), NA, censorT),
-      'censorA'= ifelse(missing(censorA), NA, censorA),
-      'baseCorr'= baseCorr,
-      'baseVars'= baseVars,
-      'alphaVar'= alphaVar,
-      'betaVar'= betaVar,
-      'mstS'= mstS,
-      'mstT'= mstT,
+      'N' = N,
+      'ni' = ni,
+      'gammaWei' = gammaWei,
+      'censorT' = ifelse(missing(censorT), NA, censorT),
+      'censorA' = ifelse(missing(censorA), NA, censorA),
+      'baseCorr' = baseCorr,
+      'baseVars' = baseVars,
+      'alphaVar' = alphaVar,
+      'betaVar' = betaVar,
+      'mstS' = mstS,
+      'mstT' = mstT,
       'alpha' = alpha,
       'beta' = beta,
       'pars' = pars,
@@ -518,16 +537,16 @@ simData <- function(method = c('re', 'cc', 'mx')) {
     )
     
     if (method == 'mx') {
-      ATTRs$indCorr <- indCorr        
+      ATTRs$indCorr <- indCorr
       
       # Second stage: survival times ***************************************** #
       # Y, the truncated normal random variables
       #   library('msm')
-      Y <- rtnorm(n = ni * N, lower=0)
+      Y <- rtnorm(n = ni * N, lower = 0)
       if (indCorr) {
         Y <- cbind(Y, Y)
       } else {
-        Y <- cbind(Y, rtnorm(n = ni * N, lower=0))
+        Y <- cbind(Y, rtnorm(n = ni * N, lower = 0))
       }
       
       # lambda, the exponential random variables
@@ -537,13 +556,15 @@ simData <- function(method = c('re', 'cc', 'mx')) {
       # S and T, the times
       deltaS <- exp(pars[, 1] + pars[, 3] * data$trt)
       deltaT <- exp(pars[, 2] + pars[, 4] * data$trt)
-      data$S <- deltaS * (Y[, 1] * sqrt(2 * lambdaS))^(1 / gammaWei[1])
-      data$T <- deltaT * (Y[, 2] * sqrt(2 * lambdaT))^(1 / gammaWei[2])
+      data$S <-
+        deltaS * (Y[, 1] * sqrt(2 * lambdaS)) ^ (1 / gammaWei[1])
+      data$T <-
+        deltaT * (Y[, 2] * sqrt(2 * lambdaT)) ^ (1 / gammaWei[2])
       # ********************************************************************** #
       
-      ATTRs$kTau <- mean(
-        cor(data$S[data$trt == -.5], data$T[data$trt == -.5], method='kendall'),
-        cor(data$S[data$trt == 0.5], data$T[data$trt == 0.5], method='kendall'))
+      ATTRs$kTau <- mean(cor(data$S[data$trt == -.5], data$T[data$trt == -.5], method =
+                               'kendall'),
+                         cor(data$S[data$trt == 0.5], data$T[data$trt == 0.5], method = 'kendall'))
     } else {
       indCorr <- NULL
       ATTRs$kTau <- kTau
@@ -557,24 +578,27 @@ simData <- function(method = c('re', 'cc', 'mx')) {
         # Second stage: survival times *************************************** #
         # Weibull hazard:
         # h(t) = lambda gamma x^(gamma-1)
-        lambda.S <- exp(pars[, 1] + pars[, 3] * data$trt + indFrailty)
-        lambda.T <- exp(pars[, 2] + pars[, 4] * data$trt + indFrailty)
+        lambda.S <-
+          exp(pars[, 1] + pars[, 3] * data$trt + indFrailty)
+        lambda.T <-
+          exp(pars[, 2] + pars[, 4] * data$trt + indFrailty)
         
         # Weibull hazard, parametrization as in rweibull:
         # h(t) = shape scale^(-shape) x^(shape-1)
         # shape = gamma
         # scale = lambda^(-1/gamma)
         shape.S <- gammaWei[1]
-        scale.S <- lambda.S^-(1/shape.S)
-        shape.T <- gammaWei[2]    
-        scale.T <- lambda.T^-(1/shape.T)
+        scale.S <- lambda.S ^ -(1 / shape.S)
+        shape.T <- gammaWei[2]
+        scale.T <- lambda.T ^ -(1 / shape.T)
         
         # S and T, the times
-        data$S <- rweibull(nrow(data), shape = shape.S, scale = scale.S)
-        data$T <- rweibull(nrow(data), shape = shape.T, scale = scale.T)
-        # ******************************************************************** #                
+        data$S <-
+          rweibull(nrow(data), shape = shape.S, scale = scale.S)
+        data$T <-
+          rweibull(nrow(data), shape = shape.T, scale = scale.T)
+        # ******************************************************************** #
       } else {
-        
         # Individ2ual-level
         theta <- 2 * kTau / (1 - kTau)
         # ******************************************************************** #
@@ -587,12 +611,13 @@ simData <- function(method = c('re', 'cc', 'mx')) {
         
         # S times
         US <- runif(nrow(data), 0, 1)
-        data$S <- (-log(US) / lambda.S)^(1/gammaWei[1])
+        data$S <- (-log(US) / lambda.S) ^ (1 / gammaWei[1])
         
         # T times | S times
         UT <- runif(nrow(data), 0, 1)
-        UT_prime <- ((UT^(-theta / (1+theta)) - 1) * US^(-theta) + 1)^(-1/theta)
-        data$T <- (-log(UT_prime) / lambda.T)^(1/gammaWei[2])
+        UT_prime <-
+          ((UT ^ (-theta / (1 + theta)) - 1) * US ^ (-theta) + 1) ^ (-1 / theta)
+        data$T <- (-log(UT_prime) / lambda.T) ^ (1 / gammaWei[2])
         # ******************************************************************** #
         #     plot(data$S, data$T, log='xy', col=data$trt+1.5)
       }
@@ -603,9 +628,11 @@ simData <- function(method = c('re', 'cc', 'mx')) {
     # Random censoring
     if (!missing(censorT)) {
       findK <- Vectorize(function(logK) {
-        (mean(runif(10 * length(data$T), 0, exp(logK)) < data$T) - censorT)^2
+        (mean(runif(10 * length(data$T), 0, exp(logK)) < data$T) - censorT) ^ 2
+      })
+      suppressWarnings({
+        k <- exp(optim(log(max(data$T)), findK)$par)
       })
-      suppressWarnings({k <- exp(optim(log(max(data$T)), findK)$par)})
       data$C <- runif(length(data$T), 0, k)
     }
     # Administrative censoring
@@ -618,9 +645,9 @@ simData <- function(method = c('re', 'cc', 'mx')) {
     data$timeS <- pmin(data$C, data$S)
     data$statusS <- mapply('>=', data$C, data$S) * 1
     # kTau <- cor(data$S, data$T, method='kendall')
-    kTau <- mean(
-      cor(data$S[data$trt == -.5], data$T[data$trt == -.5], method='kendall'),
-      cor(data$S[data$trt == 0.5], data$T[data$trt == 0.5], method='kendall'))
+    kTau <- mean(cor(data$S[data$trt == -.5], data$T[data$trt == -.5], method =
+                       'kendall'),
+                 cor(data$S[data$trt == 0.5], data$T[data$trt == 0.5], method = 'kendall'))
     data <- data[, !(names(data) %in% c('C', 'T', 'S'))]
     # ************************************************************************ #
     attributes(data) <- c(attributes(data), ATTRs)
